@@ -48,9 +48,11 @@ def start_host(address=None, port=None):
             if isinstance(l, int):
                 level = l
         logger.setLevel(level)
-    info('connecting to neovim')
+    pass # replaces next logging statement
+    #info('connecting to neovim')
     vim = connect(address, port, vim_compatible=True)
-    info('connected to neovim')
+    pass # replaces next logging statement
+    #info('connected to neovim')
     with PluginHost(vim, discovered_plugins=[ScriptHost]) as host:
         host.run()
 
